@@ -594,7 +594,7 @@ class Calculation(InputTemplate):
             l = self.lattice
             l = l.split('/')
             l = l[-1]
-        identistring = "-".join([prefix, l, str(ts), ps])
+        identistring = "-".join([prefix, l, str(ts), str(ps)])
         return identistring
 
     def create_folders(self, prefix=None):
@@ -731,4 +731,4 @@ def read_inputfile(file):
                 calc.pressure = combo[1]
                 calc.temperature = combo[2]
                 calculations.append(calc)
-    return calculations
\ No newline at end of file
+    return calculations
